#[repr(C)]pub struct File {
pub ptr: Box<Arc<Mutex<File>>>,
pub path: AzString,
pub run_destructor: bool,
}Expand description
Thread-safe file handle with path tracking for the C API.
Fields
ptr: Box<Arc<Mutex<File>>>path: AzStringrun_destructor: boolImplementations
Sourceimpl File
impl File
Sourcepub fn open(path: &str) -> Option<Self>
pub fn open(path: &str) -> Option<Self>
Opens a file in read-only mode, returning None on failure.
Sourcepub fn create(path: &str) -> Option<Self>
pub fn create(path: &str) -> Option<Self>
Creates a file (truncating if it exists), returning None on failure.
Sourcepub fn read_to_string(&mut self) -> Option<AzString>
pub fn read_to_string(&mut self) -> Option<AzString>
Reads the file at self.path into a string.
Sourcepub fn read_to_bytes(&mut self) -> Option<U8Vec>
pub fn read_to_bytes(&mut self) -> Option<U8Vec>
Reads the file at self.path into a byte vector.
Sourcepub fn write_string(&mut self, string: &str) -> Option<()>
pub fn write_string(&mut self, string: &str) -> Option<()>
Writes a string to the file handle.
Sourcepub fn write_bytes(&mut self, bytes: &[u8]) -> Option<()>
pub fn write_bytes(&mut self, bytes: &[u8]) -> Option<()>
Writes bytes to the file handle and syncs to disk.