fmt_string

Function fmt_string 

pub fn fmt_string(format: AzString, args: FmtArgVec) -> String
Formats format by substituting placeholders with values from args. Returns the error message as a string on failure (for C FFI ergonomics).