ScrollInput

Struct ScrollInput 

pub struct ScrollInput {
    pub dom_id: DomId,
    pub node_id: NodeId,
    pub delta: LogicalPosition,
    pub timestamp: Instant,
    pub source: ScrollInputSource,
}
A single scroll input event to be processed by the physics timer.

Scroll inputs are recorded by the platform event handler and consumed by the scroll physics timer callback. This decouples input recording from physics simulation.

Fields

dom_id: DomId

DOM containing the scrollable node

node_id: NodeId

Target scroll node

delta: LogicalPosition

Scroll delta (positive = scroll down/right)

timestamp: Instant

When this input was recorded

source: ScrollInputSource

How this input should be processed