pub struct SizingCacheEntry {
pub available_size: LogicalSize,
pub result_size: LogicalSize,
pub baseline: Option<f32>,
pub escaped_top_margin: Option<f32>,
pub escaped_bottom_margin: Option<f32>,
}Expand description
Cache entry for sizing (ComputeSize mode) — stores NO positions.
This is the lightweight entry stored in the 9 measurement slots. It records what constraints were provided and what size resulted, enabling Taffy’s “result matches request” optimization.
Fields
available_size: LogicalSizeThe available size that was provided as input.
result_size: LogicalSizeThe computed border-box size (output).
baseline: Option<f32>Baseline for inline alignment (if applicable).
escaped_top_margin: Option<f32>First child’s escaped top margin (CSS 2.2  8.3.1).
escaped_bottom_margin: Option<f32>Last child’s escaped bottom margin (CSS 2.2  8.3.1).