pub struct WindowLogicalRect(pub LogicalRect);Expand description
A LogicalRect known to be in absolute window coordinates (as output
by the layout engine). All spatial bounds stored in DisplayListItem use
this type so that the compositor is forced to convert them to
frame-relative coordinates before passing them to WebRender.
Coordinate-space contract
- Layout engine produces
WindowLogicalRectvalues. - Compositor converts via
resolve_rect()→ WebRenderLayoutRect. - Passing a
WindowLogicalRectdirectly to a WebRender push function is a type error (it wrapsLogicalRect, notLayoutRect).
See doc/SCROLL_COORDINATE_ARCHITECTURE.md for background.
Tuple Fields
0: LogicalRectImplementations
Sourceimpl WindowLogicalRect
impl WindowLogicalRect
pub const fn new(origin: LogicalPosition, size: LogicalSize) -> Self
pub const fn zero() -> Self
Sourcepub const fn inner(&self) -> &LogicalRect
pub const fn inner(&self) -> &LogicalRect
Access the inner LogicalRect (still in window space – the caller is
responsible for applying any offset conversion).
pub const fn into_inner(self) -> LogicalRect
pub fn origin(&self) -> LogicalPosition
pub fn size(&self) -> LogicalSize