Module fc

Module fc 

Formatting context layout (block, inline, table, and flex/grid via Taffy)

Structs

BfcState
Manages all layout state for a single Block Formatting Context. This struct is created by the BFC root and lives for the duration of its layout.
BorderInfo
Information about a border for conflict resolution
FloatingContext
Manages the state of all floated elements within a Block Formatting Context. +spec:floats:970b4c - Implements CSS29.5 float positioning and flow interaction
LayoutConstraints
Input constraints for a layout function.
LayoutOutput
The result of laying out a formatting context.
MarginCollapseContext
Manages vertical margin collapsing within a BFC.
TableCellInfo
Information about a table cell for layout
TableColumnInfo
Lays out a Table Formatting Context. Table column information for layout calculations

Enums

BorderSource
Source of a border in the border conflict resolution algorithm
OverflowBehavior
The CSS overflow property behavior.
TextAlign
Text alignment options

Constants

DEFAULT_SCROLLBAR_WIDTH_PX
Default scrollbar width in pixels (CSS scrollbar-width: auto).

Functions

check_scrollbar_necessity
Helper to determine if scrollbars are needed.
collapse_margins
Calculates a single collapsed margin from two adjoining vertical margins.
convert_font_style
Helper: Convert StyleFontStyle to text3::cache::FontStyle
convert_font_weight
Helper: Convert StyleFontWeight to FcWeight
layout_formatting_context
Main dispatcher for formatting context layout.
layout_initial_letter
Computes the geometric exclusion area for an initial letter (drop cap).
layout_table_fc
Main function to layout a table formatting context
split_text_for_whitespace
Splits text content into InlineContent items based on white-space CSS property.
translate_taffy_point_back
translate_taffy_size_back