pub struct IntrinsicSizes {
pub min_content_width: f32,
pub max_content_width: f32,
pub preferred_width: Option<f32>,
pub min_content_height: f32,
pub max_content_height: f32,
pub preferred_height: Option<f32>,
}Expand description
Represents the intrinsic sizing information for an element, calculated without knowledge of the final containing block size.
Fields
min_content_width: f32The narrowest possible width, e.g., the width of the longest word.
max_content_width: f32The preferred width if infinite horizontal space is available.
preferred_width: Option<f32>The width specified by CSS properties, if any.
min_content_height: f32The height of the element at its min_content_width.
max_content_height: f32The height of the element at its max_content_width.
preferred_height: Option<f32>The height specified by CSS properties, if any.
Implementations