pub struct ResolvedBoxProps {
pub margin: EdgeSizes,
pub padding: EdgeSizes,
pub border: EdgeSizes,
pub margin_auto: MarginAuto,
}Expand description
A fully resolved representation of a node’s box model properties.
All values are in pixels. This is the result of resolving UnresolvedBoxProps
against a containing block.
Fields
margin: EdgeSizespadding: EdgeSizesborder: EdgeSizesmargin_auto: MarginAutoTracks which margins are set to auto.
CSS 2.2  10.3.3: If both margin-left and margin-right are auto,
their used values are equal, centering the element within its container.
Implementations
Sourceimpl ResolvedBoxProps
impl ResolvedBoxProps
Sourcepub fn inner_size(
&self,
outer_size: LogicalSize,
wm: LayoutWritingMode,
) -> LogicalSize
pub fn inner_size( &self, outer_size: LogicalSize, wm: LayoutWritingMode, ) -> LogicalSize
Calculates the inner content-box size from an outer border-box size, correctly accounting for the specified writing mode.