is_node_contenteditable

Function is_node_contenteditable 

pub fn is_node_contenteditable(styled_dom: &StyledDom, node_id: NodeId) -> bool
Checks if a node has the contenteditable attribute set directly.

Returns true if:

  • The node has contenteditable: true set via .set_contenteditable(true)
  • OR the node has contenteditable attribute set to true

This does NOT check inheritance - use is_node_contenteditable_inherited for that.