Module layout_tree

Module layout_tree 

Layout tree construction from a styled DOM, including anonymous box generation

Structs

CachedInlineLayout
Cached inline layout result with the constraints used to compute it.
ComputedLayoutStyle
Pre-computed CSS properties needed during layout.
IfcId
Unique identifier for an Inline Formatting Context (IFC).
IfcMembership
Tracks a layout node’s membership in an Inline Formatting Context.
InlineItemMetrics
Per-item metrics cached from the last IFC layout.
LayoutNode
A layout tree node representing the CSS box model.
LayoutNodeCold
Cold layout node fields — construction / reconciliation / debugging only.
LayoutNodeHot
Hot layout node fields — accessed on every node in every layout pass.
LayoutNodeWarm
Warm layout node fields — accessed frequently but not on every node.
LayoutTree
The complete layout tree structure.
LayoutTreeBuilder
Incrementally builds a LayoutTree from a StyledDom.
LayoutTreeMemoryReport
Approximate per-field heap-byte breakdown of a LayoutTree.
SubtreeHash
A hash that represents the content and style of a node PLUS all of its descendants. If two SubtreeHashes are equal, their entire subtrees are considered identical for layout purposes.

Enums

AnonymousBoxType
Types of anonymous boxes that can be generated
DirtyFlag
Represents the invalidation state of a layout node.
PseudoElement
CSS pseudo-elements that can be generated

Functions

generate_layout_tree
Generate layout tree from styled DOM with proper anonymous box generation
get_display_type
is_block_level
is_whitespace_only_text
CSS 2.2 Section 17.2.1 - Anonymous box generation, Stage 1: