PaginationContext

Struct PaginationContext 

pub struct PaginationContext<'a> {
    pub geometer: &'a PageGeometer,
    pub break_avoid_depth: usize,
    pub repeated_headers: Vec<RepeatedTableHeader>,
}
Context for pagination during layout.

This is passed into layout functions to allow them to make page-aware decisions.

Fields

geometer: &'a PageGeometer

The page geometry calculator

break_avoid_depth: usize

Accumulated break-inside: avoid depth from ancestors

repeated_headers: Vec<RepeatedTableHeader>

Track table headers that need to repeat on new pages

Implementations

Source

impl<'a> PaginationContext<'a>

pub fn new(geometer: &'a PageGeometer) -> Self

pub fn enter_avoid_break(&mut self)

Enter a box with break-inside: avoid

pub fn exit_avoid_break(&mut self)

Exit a box with break-inside: avoid

pub fn is_avoiding_breaks(&self) -> bool

Check if we’re inside an ancestor with break-inside: avoid

pub fn register_repeated_header( &mut self, inject_at_y: f32, header_items: Vec<usize>, header_height: f32, )

Register a table header for repetition on subsequent pages.