Module positioning

Module positioning 

Final positioning of layout nodes (relative, absolute, and fixed schemes)

Functions

adjust_relative_positions
Final pass to shift relatively positioned elements from their static flow position.
adjust_sticky_positions
Adjusts positions of sticky-positioned elements based on scroll offset.
get_position_type
Looks up the position property using the compact-cache-aware getter.
position_out_of_flow_elements
After the main layout pass, this function iterates through the tree and correctly calculates the final positions of out-of-flow elements (absolute, fixed).