pub struct StickyConstraints {
pub top_inset: f32,
pub right_inset: f32,
pub bottom_inset: f32,
pub left_inset: f32,
pub normal_flow_position: LogicalPosition,
pub border_box_size: LogicalSize,
pub scrollport: LogicalRect,
}Expand description
Sticky positioning constraints computed at layout time. At scroll time, the sticky box’s position is clamped so that it remains within the sticky view rectangle (scrollport inset by these values).
Fields
top_inset: f32Inset from the top edge of the nearest scrollport (0 if auto).
right_inset: f32Inset from the right edge of the nearest scrollport (0 if auto).
bottom_inset: f32Inset from the bottom edge of the nearest scrollport (0 if auto).
left_inset: f32Inset from the left edge of the nearest scrollport (0 if auto).
normal_flow_position: LogicalPositionNormal-flow position of the sticky element (border-box origin).
border_box_size: LogicalSizeBorder-box size of the sticky element.
scrollport: LogicalRectThe scrollport rect (content-box of nearest scroll container).