Module sizing

Module sizing 

Intrinsic and used size calculations for layout nodes

Functions

calculate_intrinsic_sizes
Phase 2a: Calculate intrinsic sizes (bottom-up pass) // +spec:display-contents:f12d4e - intrinsic sizing: size determined by contents, not context
calculate_used_size_for_node
Calculates the used size of a single node based on its CSS properties and the available space provided by its containing block.
collect_inline_content
extract_text_from_node
resolve_percentage_with_box_model
Resolves a percentage value against the containing block dimension.