pub enum Hyphens {
None,
Manual,
Auto,
}Expand description
Controls whether hyphenation is allowed to create soft wrap opportunities.
Variants
None
No hyphenation: U+00AD soft hyphens are not treated as break points.
Manual
Only break at manually-inserted soft hyphens (U+00AD) or explicit hyphens.
Auto
The UA may automatically hyphenate words in addition to manual opportunities.