LineHeight

Enum LineHeight 

pub enum LineHeight {
    Normal,
    Px(f32),
}
CSS line-height value.

Normal defers resolution to the point where font metrics are available, computing (ascent + |descent| + lineGap) / upem * fontSize. Px is an already-resolved pixel value from an explicit CSS declaration (e.g. line-height: 1.5Px(fontSize * 1.5)).

Variants



Normal

line-height: normal — resolve from font metrics at layout time



Px(f32)

Pre-resolved pixel value (from CSS line-height: <number|length|percentage>)

Implementations

Source

impl LineHeight

pub fn resolve( &self, font_size_px: f32, ascent: f32, descent: f32, line_gap: f32, units_per_em: u16, ) -> f32

Resolve to a pixel value, using font metrics when Normal.

ascent, descent (negative in OpenType convention), line_gap are in font units. font_size_px and units_per_em are used to scale.

pub fn resolve_with_metrics( &self, font_size_px: f32, metrics: &LayoutFontMetrics, ) -> f32

Resolve using a LayoutFontMetrics struct for convenience.