pub enum OverflowWrap {
Normal,
Anywhere,
BreakWord,
}Expand description
CSS overflow-wrap (aka word-wrap) property.
Controls whether an otherwise unbreakable sequence of characters may be broken at an arbitrary point to prevent overflow.
Variants
Normal
No special break opportunities are introduced.
Anywhere
Break at arbitrary points if no other break points exist.
Soft wrap opportunities from anywhere ARE considered
when calculating min-content intrinsic sizes.
BreakWord
Same as anywhere except soft wrap opportunities introduced
by break-word are NOT considered when calculating
min-content intrinsic sizes.