WordBreak

Enum WordBreak 

pub enum WordBreak {
    Normal,
    BreakAll,
    KeepAll,
}

Variants



Normal

Normal break rules: CJK characters break between each other, non-CJK text only breaks at spaces/hyphens.



BreakAll

Allow breaks between any two characters, including within Latin words.



KeepAll

Suppress breaks between CJK characters (treat them like Latin words, only breaking at spaces). Sequences of CJK characters do not break.