Module default

Module default 

Default / concrete implementations of the text3 trait abstractions.

This module bridges the generic text3 layout engine and the concrete FontRef / ParsedFont types. It provides:

  • ParsedFontTrait implementation for FontRef
  • Font loading via PathLoader
  • The core shape_text_internal shaping function

Structs

PathLoader
A FontLoader that parses font data from a byte slice.

Traits

FontRefExt
Extension trait for FontRef to provide access to font bytes and metrics

Functions

font_ref_from_bytes
Creates a FontRef from font bytes by parsing them into a ParsedFont.
shape_text_for_parsed_font
Public helper function to shape text for ParsedFont, returning Glyph This is used by the ParsedFontTrait implementation for ParsedFont