delete_forward

Function delete_forward 

pub fn delete_forward(
    content: &mut Vec<InlineContent>,
    cursor: &TextCursor,
) -> (Vec<InlineContent>, TextCursor)
Deletes one grapheme cluster forward from the cursor.

The cursor’s affinity determines the actual cursor position:

  • Leading: Cursor is at start of cluster, delete the current grapheme
  • Trailing: Cursor is at end of cluster, delete the next grapheme