pub fn thread_sleep_ns(nanoseconds: u64) -> EmptyStructExpand description
Sleeps the current thread for the specified number of nanoseconds.
Arguments
nanoseconds- Number of nanoseconds to sleep
pub fn thread_sleep_ns(nanoseconds: u64) -> EmptyStructSleeps the current thread for the specified number of nanoseconds.
nanoseconds - Number of nanoseconds to sleep