pub fn thread_sleep_us(microseconds: u64) -> EmptyStructExpand description
Sleeps the current thread for the specified number of microseconds.
Arguments
microseconds- Number of microseconds to sleep
pub fn thread_sleep_us(microseconds: u64) -> EmptyStructSleeps the current thread for the specified number of microseconds.
microseconds - Number of microseconds to sleep