pub type LibraryReceiveThreadMsgCallbackType = extern "C" fn(*const c_void) -> OptionThreadReceiveMsg;Expand description
Callback type for receiving messages from a background thread
pub type LibraryReceiveThreadMsgCallbackType = extern "C" fn(*const c_void) -> OptionThreadReceiveMsg;Callback type for receiving messages from a background thread