pub type ThreadCallbackType = extern "C" fn(RefAny, ThreadSender, ThreadReceiver);Expand description
Callback type for the function that runs in the background thread
pub type ThreadCallbackType = extern "C" fn(RefAny, ThreadSender, ThreadReceiver);Callback type for the function that runs in the background thread