pub type ThreadDestructorCallbackType = extern "C" fn(*mut ThreadInner);Expand description
Callback type for the destructor that cleans up a ThreadInner
pub type ThreadDestructorCallbackType = extern "C" fn(*mut ThreadInner);Callback type for the destructor that cleans up a ThreadInner