Module timer

Module timer 

Timer callback wrappers for the C API. Timer callback information and utilities for azul-layout

This module provides Timer, TimerCallbackInfo and related types for managing timers that run on the main UI thread.

Structs

Timer
A Timer is a function that runs on every frame or at intervals.
TimerCallback
Callback that runs on every frame on the main thread
TimerCallbackInfo
Information passed to timer callbacks.

Enums

OptionTimer
Optional Timer type for API compatibility

Type Aliases

TimerCallbackType
Callback type for timers