pub type CardOnClickCallbackType = extern "C" fn(RefAny, CallbackInfo) -> Update;Expand description
Callback function type invoked when the card container is clicked.
pub type CardOnClickCallbackType = extern "C" fn(RefAny, CallbackInfo) -> Update;Callback function type invoked when the card container is clicked.