pub type CheckBoxOnToggleCallbackType = extern "C" fn(RefAny, CallbackInfo, CheckBoxState) -> Update;Expand description
Callback function type invoked when the checkbox is toggled.
pub type CheckBoxOnToggleCallbackType = extern "C" fn(RefAny, CallbackInfo, CheckBoxState) -> Update;Callback function type invoked when the checkbox is toggled.