#[repr(C)]pub struct ColorInput {
pub color_input_state: ColorInputStateWrapper,
pub style: CssPropertyWithConditionsVec,
}Expand description
Rectangular input that displays a color and triggers a callback when clicked.
Fields
color_input_state: ColorInputStateWrapperstyle: CssPropertyWithConditionsVecImplementations
Sourceimpl ColorInput
impl ColorInput
Sourcepub fn set_on_value_change<I: Into<ColorInputOnValueChangeCallback>>(
&mut self,
data: RefAny,
callback: I,
)
pub fn set_on_value_change<I: Into<ColorInputOnValueChangeCallback>>( &mut self, data: RefAny, callback: I, )
Sets the callback invoked when the color value changes.
Sourcepub fn with_on_value_change<C: Into<ColorInputOnValueChangeCallback>>(
self,
data: RefAny,
callback: C,
) -> Self
pub fn with_on_value_change<C: Into<ColorInputOnValueChangeCallback>>( self, data: RefAny, callback: C, ) -> Self
Builder-style method to set the value-change callback.
Sourcepub fn swap_with_default(&mut self) -> Self
pub fn swap_with_default(&mut self) -> Self
Replaces self with a default ColorInput and returns the previous value.