#[repr(C)]pub struct ColorInputStateWrapper {
pub inner: ColorInputState,
pub title: AzString,
pub on_value_change: OptionColorInputOnValueChange,
}Expand description
Wrapper around ColorInputState that includes a title and an optional value-change callback.
Fields
inner: ColorInputStatetitle: AzStringon_value_change: OptionColorInputOnValueChangeTrait Implementations
Sourceimpl Clone for ColorInputStateWrapper
impl Clone for ColorInputStateWrapper
Sourcefn clone(&self) -> ColorInputStateWrapper
fn clone(&self) -> ColorInputStateWrapper
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColorInputStateWrapper
impl Debug for ColorInputStateWrapper
Sourceimpl Default for ColorInputStateWrapper
impl Default for ColorInputStateWrapper
Sourceimpl PartialEq for ColorInputStateWrapper
impl PartialEq for ColorInputStateWrapper
Sourcefn eq(&self, other: &ColorInputStateWrapper) -> bool
fn eq(&self, other: &ColorInputStateWrapper) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ColorInputStateWrapper
impl PartialOrd for ColorInputStateWrapper
impl StructuralPartialEq for ColorInputStateWrapper