#[repr(C)]pub struct DatePicker {
pub state: DatePickerStateWrapper,
pub container_style: CssPropertyWithConditionsVec,
}Expand description
A calendar date picker.
Fields
state: DatePickerStateWrappercontainer_style: CssPropertyWithConditionsVecStyle for the outer container.
Implementations
Sourceimpl DatePicker
impl DatePicker
Sourcepub fn create(year: u32, month: u32, day: u32) -> Self
pub fn create(year: u32, month: u32, day: u32) -> Self
Creates a new DatePicker showing year/month with day selected.
month is clamped to 1..=12 and day to 1..=days_in_month.
Sourcepub fn set_on_change<C: Into<DatePickerOnChangeCallback>>(
&mut self,
data: RefAny,
callback: C,
)
pub fn set_on_change<C: Into<DatePickerOnChangeCallback>>( &mut self, data: RefAny, callback: C, )
Sets the callback invoked when the selection or month changes.
Sourcepub fn with_on_change<C: Into<DatePickerOnChangeCallback>>(
self,
data: RefAny,
callback: C,
) -> Self
pub fn with_on_change<C: Into<DatePickerOnChangeCallback>>( self, data: RefAny, callback: C, ) -> Self
Builder variant of Self::set_on_change.
Sourcepub fn swap_with_default(&mut self) -> Self
pub fn swap_with_default(&mut self) -> Self
Replaces self with the default value and returns the original.
pub fn dom(self) -> Dom