Module file_input

Module file_input 

File input widget File input button, same as Button, but triggers a user-supplied path-change callback when clicked

Structs

FileInput
FileInputOnPathChange
FileInputOnPathChangeCallback
FileInputState
Current state of the file input (selected path)
FileInputStateWrapper

Enums

OptionFileInputOnPathChange

Statics

FILE_INPUT_ON_PATH_CHANGE_INVOKER
Process-global slot for this callback kind’s host-side invoker.

Functions

AzApp_setFileInputOnPathChangeCallbackInvoker
Register the host-side invoker for this callback kind.
AzFileInputOnPathChangeCallback_createFromHostHandle
C-ABI export wrapping <Wrapper>::create_from_host_handle.

Type Aliases

AzFileInputOnPathChangeCallbackInvoker
Pointer-arg variant of this callback kind’s typedef.
FileInputOnPathChangeCallbackType
Callback type invoked when the file input path changes