pub type FileInputOnPathChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, FileInputState) -> Update;Expand description
Callback type invoked when the file input path changes
pub type FileInputOnPathChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, FileInputState) -> Update;Callback type invoked when the file input path changes