#[repr(C)]pub struct NodeGraphNodePosition {
pub x: f32,
pub y: f32,
}Expand description
Things only relevant to the display of the node in an interactive editor
- such as x and y position in the node graph, name, etc.
Fields
x: f32X Position of the node
y: f32Y Position of the node