pub struct OutputNodeAndIndexVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl OutputNodeAndIndexVec
impl OutputNodeAndIndexVec
pub fn new() -> OutputNodeAndIndexVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [OutputNodeAndIndex]) -> Self
pub fn from_vec(input: Vec<OutputNodeAndIndex>) -> Self
pub fn iter(&self) -> Iter<'_, OutputNodeAndIndex>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&OutputNodeAndIndex>
pub fn get(&self, index: usize) -> Option<&OutputNodeAndIndex>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionOutputNodeAndIndexwhere
OutputNodeAndIndex: Clone,
pub fn c_get(&self, index: usize) -> OptionOutputNodeAndIndexwhere
OutputNodeAndIndex: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[OutputNodeAndIndex]
pub fn as_slice(&self) -> &[OutputNodeAndIndex]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> OutputNodeAndIndexVecSlice
pub fn as_c_slice(&self) -> OutputNodeAndIndexVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> OutputNodeAndIndexVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> OutputNodeAndIndexVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const OutputNodeAndIndex
pub fn as_ptr(&self) -> *const OutputNodeAndIndex
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl OutputNodeAndIndexVec
impl OutputNodeAndIndexVec
pub fn from_copy_on_write( input: Cow<'static, [OutputNodeAndIndex]>, ) -> OutputNodeAndIndexVec
Sourcepub fn from_item(item: OutputNodeAndIndex) -> Self
pub fn from_item(item: OutputNodeAndIndex) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const OutputNodeAndIndex, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const OutputNodeAndIndex, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<OutputNodeAndIndex>
pub fn into_library_owned_vec(self) -> Vec<OutputNodeAndIndex>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl OutputNodeAndIndexVec
impl OutputNodeAndIndexVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [OutputNodeAndIndex]
pub fn as_mut_ptr(&mut self) -> *mut OutputNodeAndIndex
pub fn sort_by<F: FnMut(&OutputNodeAndIndex, &OutputNodeAndIndex) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: OutputNodeAndIndex)
pub fn insert(&mut self, index: usize, element: OutputNodeAndIndex)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<OutputNodeAndIndex>
pub fn iter_mut(&mut self) -> IterMut<'_, OutputNodeAndIndex>
pub fn into_iter(self) -> IntoIter<OutputNodeAndIndex>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)