pub type SegmentedOnChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, SegmentedState) -> Update;Expand description
Callback function type invoked when the selected segment changes.
pub type SegmentedOnChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, SegmentedState) -> Update;Callback function type invoked when the selected segment changes.