#[repr(C)]pub struct Slider {
pub slider_state: SliderStateWrapper,
pub track_style: CssPropertyWithConditionsVec,
pub thumb_style: CssPropertyWithConditionsVec,
}Expand description
A horizontal slider with a draggable thumb and a value-change callback.
Fields
slider_state: SliderStateWrappertrack_style: CssPropertyWithConditionsVecStyle for the slider track (the horizontal rail).
thumb_style: CssPropertyWithConditionsVecStyle for the draggable thumb.
Implementations
Sourceimpl Slider
impl Slider
Sourcepub fn create(value: f32, min: f32, max: f32) -> Self
pub fn create(value: f32, min: f32, max: f32) -> Self
Creates a slider with the given current value and [min, max] range.
Sourcepub fn set_value(&mut self, value: f32)
pub fn set_value(&mut self, value: f32)
Sets the current value (clamped to the range), recomputing the thumb position.
Sourcepub fn with_value(self, value: f32) -> Self
pub fn with_value(self, value: f32) -> Self
Builder-style setter for the current value.
pub fn swap_with_default(&mut self) -> Self
pub fn set_on_value_change<C: Into<SliderOnValueChangeCallback>>( &mut self, data: RefAny, on_value_change: C, )
pub fn with_on_value_change<C: Into<SliderOnValueChangeCallback>>( self, data: RefAny, on_value_change: C, ) -> Self
pub fn dom(self) -> Dom