pub type StepperOnStepChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, StepperState) -> Update;Expand description
Callback function type invoked when the current step changes.
pub type StepperOnStepChangeCallbackType = extern "C" fn(RefAny, CallbackInfo, StepperState) -> Update;Callback function type invoked when the current step changes.