pub struct TreeViewNodeVec { /* private fields */ }Implementations
Sourceimpl TreeViewNodeVec
impl TreeViewNodeVec
pub fn new() -> TreeViewNodeVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [TreeViewNode]) -> Self
pub fn from_vec(input: Vec<TreeViewNode>) -> Self
pub fn iter(&self) -> Iter<'_, TreeViewNode>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&TreeViewNode>
pub fn get(&self, index: usize) -> Option<&TreeViewNode>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionTreeViewNodewhere
TreeViewNode: Clone,
pub fn c_get(&self, index: usize) -> OptionTreeViewNodewhere
TreeViewNode: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[TreeViewNode]
pub fn as_slice(&self) -> &[TreeViewNode]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> TreeViewNodeVecSlice
pub fn as_c_slice(&self) -> TreeViewNodeVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> TreeViewNodeVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> TreeViewNodeVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const TreeViewNode
pub fn as_ptr(&self) -> *const TreeViewNode
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl TreeViewNodeVec
impl TreeViewNodeVec
pub fn from_copy_on_write( input: Cow<'static, [TreeViewNode]>, ) -> TreeViewNodeVec
Sourcepub fn from_item(item: TreeViewNode) -> Self
pub fn from_item(item: TreeViewNode) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const TreeViewNode, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const TreeViewNode, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<TreeViewNode>
pub fn into_library_owned_vec(self) -> Vec<TreeViewNode>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl TreeViewNodeVec
impl TreeViewNodeVec
pub fn as_mut_ptr(&mut self) -> *mut TreeViewNode
pub fn sort_by<F: FnMut(&TreeViewNode, &TreeViewNode) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: TreeViewNode)
pub fn insert(&mut self, index: usize, element: TreeViewNode)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<TreeViewNode>
pub fn iter_mut(&mut self) -> IterMut<'_, TreeViewNode>
pub fn into_iter(self) -> IntoIter<TreeViewNode>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)