pub struct FullWindowStateVec { /* private fields */ }Implementations
Sourceimpl FullWindowStateVec
impl FullWindowStateVec
pub const fn new() -> FullWindowStateVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [FullWindowState]) -> Self
pub const fn from_vec(input: Vec<FullWindowState>) -> Self
pub fn iter(&self) -> Iter<'_, FullWindowState>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&FullWindowState>
pub fn get(&self, index: usize) -> Option<&FullWindowState>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionFullWindowStatewhere
FullWindowState: Clone,
pub fn c_get(&self, index: usize) -> OptionFullWindowStatewhere
FullWindowState: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[FullWindowState]
pub fn as_slice(&self) -> &[FullWindowState]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub const fn as_c_slice(&self) -> FullWindowStateVecSlice
pub const fn as_c_slice(&self) -> FullWindowStateVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> FullWindowStateVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> FullWindowStateVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub const fn as_ptr(&self) -> *const FullWindowState
pub const fn as_ptr(&self) -> *const FullWindowState
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl FullWindowStateVec
impl FullWindowStateVec
pub fn from_copy_on_write( input: Cow<'static, [FullWindowState]>, ) -> FullWindowStateVec
Sourcepub fn from_item(item: FullWindowState) -> Self
pub fn from_item(item: FullWindowState) -> Self
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const FullWindowState, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const FullWindowState, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<FullWindowState>
pub fn into_library_owned_vec(self) -> Vec<FullWindowState>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated