get_body_node

Function get_body_node 

pub fn get_body_node(
    root_nodes: &[XmlNodeChild],
) -> Result<&XmlNode, DomXmlParseError>
Find the one and only <body> node, return error if there is no app node or there are multiple app nodes

Errors

Returns an error if the document has no <body> node.