pub struct ComponentArgumentVec { /* private fields */ }Implementations
Sourceimpl ComponentArgumentVec
impl ComponentArgumentVec
pub fn new() -> ComponentArgumentVec
pub fn with_capacity(cap: usize) -> ComponentArgumentVec
pub const fn from_const_slice( input: &'static [ComponentArgument], ) -> ComponentArgumentVec
pub fn from_vec(input: Vec<ComponentArgument>) -> ComponentArgumentVec
pub fn iter(&self) -> Iter<'_, ComponentArgument>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&ComponentArgument>
pub fn get(&self, index: usize) -> Option<&ComponentArgument>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionComponentArgumentwhere
ComponentArgument: Clone,
pub fn c_get(&self, index: usize) -> OptionComponentArgumentwhere
ComponentArgument: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[ComponentArgument]
pub fn as_slice(&self) -> &[ComponentArgument]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> ComponentArgumentVecSlice
pub fn as_c_slice(&self) -> ComponentArgumentVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> ComponentArgumentVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> ComponentArgumentVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const ComponentArgument
pub fn as_ptr(&self) -> *const ComponentArgument
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl ComponentArgumentVec
impl ComponentArgumentVec
pub fn from_copy_on_write( input: Cow<'static, [ComponentArgument]>, ) -> ComponentArgumentVec
Sourcepub fn from_item(item: ComponentArgument) -> ComponentArgumentVec
pub fn from_item(item: ComponentArgument) -> ComponentArgumentVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const ComponentArgument,
len: usize,
) -> ComponentArgumentVec
pub unsafe fn copy_from_ptr( ptr: *const ComponentArgument, len: usize, ) -> ComponentArgumentVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> ComponentArgumentVec
pub fn clone_self(&self) -> ComponentArgumentVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<ComponentArgument>
pub fn into_library_owned_vec(self) -> Vec<ComponentArgument>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourceimpl ComponentArgumentVec
impl ComponentArgumentVec
pub fn as_mut_ptr(&mut self) -> *mut ComponentArgument
pub fn sort_by<F>(&mut self, compare: F)
pub fn push(&mut self, value: ComponentArgument)
pub fn insert(&mut self, index: usize, element: ComponentArgument)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<ComponentArgument>
pub fn iter_mut(&mut self) -> IterMut<'_, ComponentArgument>
pub fn into_iter(self) -> IntoIter<ComponentArgument>
pub fn append(&mut self, other: &mut ComponentArgumentVec)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)