pub struct ComponentCallbackArgVec { /* private fields */ }Implementations
Sourceimpl ComponentCallbackArgVec
impl ComponentCallbackArgVec
pub fn new() -> ComponentCallbackArgVec
pub fn with_capacity(cap: usize) -> ComponentCallbackArgVec
pub const fn from_const_slice( input: &'static [ComponentCallbackArg], ) -> ComponentCallbackArgVec
pub fn from_vec(input: Vec<ComponentCallbackArg>) -> ComponentCallbackArgVec
pub fn iter(&self) -> Iter<'_, ComponentCallbackArg>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&ComponentCallbackArg>
pub fn get(&self, index: usize) -> Option<&ComponentCallbackArg>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionComponentCallbackArgwhere
ComponentCallbackArg: Clone,
pub fn c_get(&self, index: usize) -> OptionComponentCallbackArgwhere
ComponentCallbackArg: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[ComponentCallbackArg]
pub fn as_slice(&self) -> &[ComponentCallbackArg]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> ComponentCallbackArgVecSlice
pub fn as_c_slice(&self) -> ComponentCallbackArgVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> ComponentCallbackArgVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> ComponentCallbackArgVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const ComponentCallbackArg
pub fn as_ptr(&self) -> *const ComponentCallbackArg
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl ComponentCallbackArgVec
impl ComponentCallbackArgVec
pub fn from_copy_on_write( input: Cow<'static, [ComponentCallbackArg]>, ) -> ComponentCallbackArgVec
Sourcepub fn from_item(item: ComponentCallbackArg) -> ComponentCallbackArgVec
pub fn from_item(item: ComponentCallbackArg) -> ComponentCallbackArgVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const ComponentCallbackArg,
len: usize,
) -> ComponentCallbackArgVec
pub unsafe fn copy_from_ptr( ptr: *const ComponentCallbackArg, len: usize, ) -> ComponentCallbackArgVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> ComponentCallbackArgVec
pub fn clone_self(&self) -> ComponentCallbackArgVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<ComponentCallbackArg>
pub fn into_library_owned_vec(self) -> Vec<ComponentCallbackArg>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated