pub struct ExternalResourceVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl ExternalResourceVec
impl ExternalResourceVec
pub fn new() -> ExternalResourceVec
pub fn with_capacity(cap: usize) -> ExternalResourceVec
pub const fn from_const_slice( input: &'static [ExternalResource], ) -> ExternalResourceVec
pub fn from_vec(input: Vec<ExternalResource>) -> ExternalResourceVec
pub fn iter(&self) -> Iter<'_, ExternalResource>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&ExternalResource>
pub fn get(&self, index: usize) -> Option<&ExternalResource>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionExternalResourcewhere
ExternalResource: Clone,
pub fn c_get(&self, index: usize) -> OptionExternalResourcewhere
ExternalResource: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[ExternalResource]
pub fn as_slice(&self) -> &[ExternalResource]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> ExternalResourceVecSlice
pub fn as_c_slice(&self) -> ExternalResourceVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> ExternalResourceVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> ExternalResourceVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const ExternalResource
pub fn as_ptr(&self) -> *const ExternalResource
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl ExternalResourceVec
impl ExternalResourceVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [ExternalResource]
pub fn as_mut_ptr(&mut self) -> *mut ExternalResource
pub fn sort_by<F>(&mut self, compare: F)
pub fn push(&mut self, value: ExternalResource)
pub fn insert(&mut self, index: usize, element: ExternalResource)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<ExternalResource>
pub fn iter_mut(&mut self) -> IterMut<'_, ExternalResource>
pub fn into_iter(self) -> IntoIter<ExternalResource>
pub fn append(&mut self, other: &mut ExternalResourceVec)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl ExternalResourceVec
impl ExternalResourceVec
pub fn from_copy_on_write( input: Cow<'static, [ExternalResource]>, ) -> ExternalResourceVec
Sourcepub fn from_item(item: ExternalResource) -> ExternalResourceVec
pub fn from_item(item: ExternalResource) -> ExternalResourceVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const ExternalResource,
len: usize,
) -> ExternalResourceVec
pub unsafe fn copy_from_ptr( ptr: *const ExternalResource, len: usize, ) -> ExternalResourceVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> ExternalResourceVec
pub fn clone_self(&self) -> ExternalResourceVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<ExternalResource>
pub fn into_library_owned_vec(self) -> Vec<ExternalResource>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated