pub struct XmlNodeChildVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl XmlNodeChildVec
impl XmlNodeChildVec
pub fn new() -> XmlNodeChildVec
pub fn with_capacity(cap: usize) -> XmlNodeChildVec
pub const fn from_const_slice(input: &'static [XmlNodeChild]) -> XmlNodeChildVec
pub fn from_vec(input: Vec<XmlNodeChild>) -> XmlNodeChildVec
pub fn iter(&self) -> Iter<'_, XmlNodeChild>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&XmlNodeChild>
pub fn get(&self, index: usize) -> Option<&XmlNodeChild>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionXmlNodeChildwhere
XmlNodeChild: Clone,
pub fn c_get(&self, index: usize) -> OptionXmlNodeChildwhere
XmlNodeChild: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[XmlNodeChild]
pub fn as_slice(&self) -> &[XmlNodeChild]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> XmlNodeChildVecSlice
pub fn as_c_slice(&self) -> XmlNodeChildVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> XmlNodeChildVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> XmlNodeChildVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const XmlNodeChild
pub fn as_ptr(&self) -> *const XmlNodeChild
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl XmlNodeChildVec
impl XmlNodeChildVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [XmlNodeChild]
pub fn as_mut_ptr(&mut self) -> *mut XmlNodeChild
pub fn sort_by<F>(&mut self, compare: F)
pub fn push(&mut self, value: XmlNodeChild)
pub fn insert(&mut self, index: usize, element: XmlNodeChild)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<XmlNodeChild>
pub fn iter_mut(&mut self) -> IterMut<'_, XmlNodeChild>
pub fn into_iter(self) -> IntoIter<XmlNodeChild>
pub fn append(&mut self, other: &mut XmlNodeChildVec)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl XmlNodeChildVec
impl XmlNodeChildVec
pub fn from_copy_on_write( input: Cow<'static, [XmlNodeChild]>, ) -> XmlNodeChildVec
Sourcepub fn from_item(item: XmlNodeChild) -> XmlNodeChildVec
pub fn from_item(item: XmlNodeChild) -> XmlNodeChildVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const XmlNodeChild,
len: usize,
) -> XmlNodeChildVec
pub unsafe fn copy_from_ptr( ptr: *const XmlNodeChild, len: usize, ) -> XmlNodeChildVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> XmlNodeChildVec
pub fn clone_self(&self) -> XmlNodeChildVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<XmlNodeChild>
pub fn into_library_owned_vec(self) -> Vec<XmlNodeChild>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated