pub struct XmlNodeVec {
pub run_destructor: bool,
/* private fields */
}Fields
run_destructor: boolWhether to run the destructor on drop (prevents double-free when cloned to C)
Implementations
Sourceimpl XmlNodeVec
impl XmlNodeVec
pub fn new() -> XmlNodeVec
pub fn with_capacity(cap: usize) -> XmlNodeVec
pub const fn from_const_slice(input: &'static [XmlNode]) -> XmlNodeVec
pub fn from_vec(input: Vec<XmlNode>) -> XmlNodeVec
pub fn iter(&self) -> Iter<'_, XmlNode>
pub fn ptr_as_usize(&self) -> usize
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&XmlNode>
pub fn get(&self, index: usize) -> Option<&XmlNode>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionXmlNode
pub fn c_get(&self, index: usize) -> OptionXmlNode
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[XmlNode]
pub fn as_slice(&self) -> &[XmlNode]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> XmlNodeVecSlice
pub fn as_c_slice(&self) -> XmlNodeVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> XmlNodeVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> XmlNodeVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl XmlNodeVec
impl XmlNodeVec
pub fn as_mut_slice_extended<'a>(&mut self) -> &'a mut [XmlNode]
pub fn as_mut_ptr(&mut self) -> *mut XmlNode
pub fn sort_by<F>(&mut self, compare: F)
pub fn push(&mut self, value: XmlNode)
pub fn insert(&mut self, index: usize, element: XmlNode)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<XmlNode>
pub fn iter_mut(&mut self) -> IterMut<'_, XmlNode>
pub fn into_iter(self) -> IntoIter<XmlNode>
pub fn append(&mut self, other: &mut XmlNodeVec)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl XmlNodeVec
impl XmlNodeVec
pub fn from_copy_on_write(input: Cow<'static, [XmlNode]>) -> XmlNodeVec
Sourcepub fn from_item(item: XmlNode) -> XmlNodeVec
pub fn from_item(item: XmlNode) -> XmlNodeVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const XmlNode, len: usize) -> XmlNodeVec
pub unsafe fn copy_from_ptr(ptr: *const XmlNode, len: usize) -> XmlNodeVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> XmlNodeVec
pub fn clone_self(&self) -> XmlNodeVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<XmlNode>
pub fn into_library_owned_vec(self) -> Vec<XmlNode>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated