#[repr(C)]pub struct SvgMultiPolygon {
pub rings: SvgPathVec,
}Fields
rings: SvgPathVecNOTE: If a ring represents a hole, simply reverse the order of points
Implementations
Sourceimpl SvgMultiPolygon
impl SvgMultiPolygon
Sourcepub const fn create(rings: SvgPathVec) -> SvgMultiPolygon
pub const fn create(rings: SvgPathVec) -> SvgMultiPolygon
Creates a new SvgMultiPolygon from a vector of paths (rings) NOTE: If a ring represents a hole, simply reverse the order of points
Sourcepub fn get_bounds(&self) -> SvgRect
pub fn get_bounds(&self) -> SvgRect
Returns the axis-aligned bounding rectangle of all rings in this multi-polygon.