pub struct SvgMultiPolygonVec { /* private fields */ }Implementations
Sourceimpl SvgMultiPolygonVec
impl SvgMultiPolygonVec
pub fn new() -> SvgMultiPolygonVec
pub fn with_capacity(cap: usize) -> SvgMultiPolygonVec
pub const fn from_const_slice( input: &'static [SvgMultiPolygon], ) -> SvgMultiPolygonVec
pub fn from_vec(input: Vec<SvgMultiPolygon>) -> SvgMultiPolygonVec
pub fn iter(&self) -> Iter<'_, SvgMultiPolygon>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&SvgMultiPolygon>
pub fn get(&self, index: usize) -> Option<&SvgMultiPolygon>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionSvgMultiPolygonwhere
SvgMultiPolygon: Clone,
pub fn c_get(&self, index: usize) -> OptionSvgMultiPolygonwhere
SvgMultiPolygon: Clone,
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[SvgMultiPolygon]
pub fn as_slice(&self) -> &[SvgMultiPolygon]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> SvgMultiPolygonVecSlice
pub fn as_c_slice(&self) -> SvgMultiPolygonVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(
&self,
start: usize,
end: usize,
) -> SvgMultiPolygonVecSlice
pub fn as_c_slice_range( &self, start: usize, end: usize, ) -> SvgMultiPolygonVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourcepub fn as_ptr(&self) -> *const SvgMultiPolygon
pub fn as_ptr(&self) -> *const SvgMultiPolygon
Returns a pointer to the Vec’s data.
Use len() to get the number of elements.
Sourceimpl SvgMultiPolygonVec
impl SvgMultiPolygonVec
pub fn from_copy_on_write( input: Cow<'static, [SvgMultiPolygon]>, ) -> SvgMultiPolygonVec
Sourcepub fn from_item(item: SvgMultiPolygon) -> SvgMultiPolygonVec
pub fn from_item(item: SvgMultiPolygon) -> SvgMultiPolygonVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(
ptr: *const SvgMultiPolygon,
len: usize,
) -> SvgMultiPolygonVec
pub unsafe fn copy_from_ptr( ptr: *const SvgMultiPolygon, len: usize, ) -> SvgMultiPolygonVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> SvgMultiPolygonVec
pub fn clone_self(&self) -> SvgMultiPolygonVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<SvgMultiPolygon>
pub fn into_library_owned_vec(self) -> Vec<SvgMultiPolygon>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated