pub struct SvgPathVec { /* private fields */ }Implementations
Sourceimpl SvgPathVec
impl SvgPathVec
pub fn new() -> SvgPathVec
pub fn with_capacity(cap: usize) -> SvgPathVec
pub const fn from_const_slice(input: &'static [SvgPath]) -> SvgPathVec
pub fn from_vec(input: Vec<SvgPath>) -> SvgPathVec
pub fn iter(&self) -> Iter<'_, SvgPath>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&SvgPath>
pub fn get(&self, index: usize) -> Option<&SvgPath>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionSvgPath
pub fn c_get(&self, index: usize) -> OptionSvgPath
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[SvgPath]
pub fn as_slice(&self) -> &[SvgPath]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> SvgPathVecSlice
pub fn as_c_slice(&self) -> SvgPathVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> SvgPathVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> SvgPathVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl SvgPathVec
impl SvgPathVec
pub fn from_copy_on_write(input: Cow<'static, [SvgPath]>) -> SvgPathVec
Sourcepub fn from_item(item: SvgPath) -> SvgPathVec
pub fn from_item(item: SvgPath) -> SvgPathVec
Creates a Vec containing a single element
Sourcepub unsafe fn copy_from_ptr(ptr: *const SvgPath, len: usize) -> SvgPathVec
pub unsafe fn copy_from_ptr(ptr: *const SvgPath, len: usize) -> SvgPathVec
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> SvgPathVec
pub fn clone_self(&self) -> SvgPathVec
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<SvgPath>
pub fn into_library_owned_vec(self) -> Vec<SvgPath>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated