#[repr(C)]pub struct SvgRect {
pub width: f32,
pub height: f32,
pub x: f32,
pub y: f32,
pub radius_top_left: f32,
pub radius_top_right: f32,
pub radius_bottom_left: f32,
pub radius_bottom_right: f32,
}Expand description
An axis-aligned rectangle with optional rounded corners.
Fields
width: f32height: f32x: f32y: f32radius_top_left: f32radius_top_right: f32radius_bottom_left: f32radius_bottom_right: f32Implementations
Sourceimpl SvgRect
impl SvgRect
Sourcepub fn union_with(&mut self, other: &SvgRect)
pub fn union_with(&mut self, other: &SvgRect)
Expands this rect to also contain other.
Sourcepub fn contains_point(&self, point: SvgPoint) -> bool
pub fn contains_point(&self, point: SvgPoint) -> bool
Note: does not incorporate rounded edges! Origin of x and y is assumed to be the top left corner
Sourcepub fn expand(
&self,
padding_top: f32,
padding_bottom: f32,
padding_left: f32,
padding_right: f32,
) -> SvgRect
pub fn expand( &self, padding_top: f32, padding_bottom: f32, padding_left: f32, padding_right: f32, ) -> SvgRect
Expands the rect with a certain amount of padding
Sourcepub fn get_center(&self) -> SvgPoint
pub fn get_center(&self) -> SvgPoint
Returns the center point of the rect.