pub type RegisterComponentFnType = extern "C" fn() -> ComponentDef;Expand description
Raw function pointer type that returns a single ComponentDef when called.
Used as the cb field in RegisterComponentFn.
pub type RegisterComponentFnType = extern "C" fn() -> ComponentDef;Raw function pointer type that returns a single ComponentDef when called.
Used as the cb field in RegisterComponentFn.