pub type RegisterComponentLibraryFnType = extern "C" fn() -> ComponentLibrary;Expand description
Raw function pointer type that returns a complete ComponentLibrary when called.
Used as the cb field in RegisterComponentLibraryFn.
pub type RegisterComponentLibraryFnType = extern "C" fn() -> ComponentLibrary;Raw function pointer type that returns a complete ComponentLibrary when called.
Used as the cb field in RegisterComponentLibraryFn.