#[repr(C)]pub struct HttpResponse {
pub status_code: u16,
pub body: U8Vec,
pub content_type: AzString,
pub content_length: u64,
pub headers: HttpHeaderVec,
}Expand description
HTTP response with status code, headers, and body
Fields
status_code: u16HTTP status code (200, 404, etc.)
body: U8VecResponse body as bytes
content_type: AzStringContent-Type header value
content_length: u64Content-Length header value (0 if unknown)
headers: HttpHeaderVecResponse headers
Implementations
Sourceimpl HttpResponse
impl HttpResponse
Sourcepub const fn is_success(&self) -> bool
pub const fn is_success(&self) -> bool
Check if the response was successful (2xx status)
Sourcepub const fn is_redirect(&self) -> bool
pub const fn is_redirect(&self) -> bool
Check if the response is a redirect (3xx status)
Sourcepub const fn is_client_error(&self) -> bool
pub const fn is_client_error(&self) -> bool
Check if the response is a client error (4xx status)
Sourcepub const fn is_server_error(&self) -> bool
pub const fn is_server_error(&self) -> bool
Check if the response is a server error (5xx status)
Sourcepub fn body_as_string(&self) -> Option<AzString>
pub fn body_as_string(&self) -> Option<AzString>
Try to convert the body to a UTF-8 string