Image decoding and encoding (wraps the image crate).
Image decoding and encoding utilities, wrapping the image crate
with Azul’s FFI-compatible types (RawImage, RawImageFormat).
- [
decode]: Decodes image bytes in any supported format into a [RawImage]. - [
encode]: Encodes a [RawImage] into various output formats (PNG, JPEG, BMP, etc.).