create_select_all_changeset

Function create_select_all_changeset 

pub fn create_select_all_changeset(
    target: DomNodeId,
    timestamp: Instant,
    layout_window: &LayoutWindow,
) -> Option<TextChangeset>
Creates a select-all changeset for the target node.

Selects all text content in the target node from the beginning to the end. Returns None if the node has no text content.