Text selection state management and clipboard content types
Note: SelectionManager has been superseded by multi_cursor on
TextEditManager and is no longer wired into the system. The live types
in this module are ClipboardContent and StyledTextRun, used for
clipboard operations.
Structs
- Click
State - Click state for detecting double/triple clicks
- Clipboard
Content - Clipboard content with both plain text and styled (HTML) representation
- Selection
Manager - Manager for text selections across all DOMs
- Styled
Text Run - Styled text run for rich clipboard content
- Styled
Text RunVec - Styled
Text RunVec Slice - C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.