Formatting context layout (block, inline, table, and flex/grid via Taffy)
Structs
- BfcState
- Manages all layout state for a single Block Formatting Context. This struct is created by the BFC root and lives for the duration of its layout.
- Border
Info - Information about a border for conflict resolution
- Floating
Context - Manages the state of all floated elements within a Block Formatting Context. +spec:floats:970b4c - Implements CSS29.5 float positioning and flow interaction
- Layout
Constraints - Input constraints for a layout function.
- Layout
Output - The result of laying out a formatting context.
- Margin
Collapse Context - Manages vertical margin collapsing within a BFC.
- Table
Cell Info - Information about a table cell for layout
- Table
Column Info - Lays out a Table Formatting Context. Table column information for layout calculations
Enums
- Border
Source - Source of a border in the border conflict resolution algorithm
- Overflow
Behavior - The CSS
overflowproperty behavior. - Text
Align - Text alignment options
Constants
- DEFAULT_
SCROLLBAR_ WIDTH_ PX - Default scrollbar width in pixels (CSS
scrollbar-width: auto).
Functions
- check_
scrollbar_ necessity - Helper to determine if scrollbars are needed.
- collapse_
margins - Calculates a single collapsed margin from two adjoining vertical margins.
- convert_
font_ style - Helper: Convert
StyleFontStyletotext3::cache::FontStyle - convert_
font_ weight - Helper: Convert
StyleFontWeighttoFcWeight - layout_
formatting_ context - Main dispatcher for formatting context layout.
- layout_
initial_ letter - Computes the geometric exclusion area for an initial letter (drop cap).
- layout_
table_ fc - Main function to layout a table formatting context
- split_
text_ for_ whitespace - Splits text content into
InlineContentitems based on white-space CSS property. - translate_
taffy_ point_ back - translate_
taffy_ size_ back