pub struct ResolvedFontChains {
pub chains: HashMap<FontChainKeyOrRef, FontFallbackChain>,
}Expand description
Resolved font chains ready for use in layout This is the result of resolving font stacks against FcFontCache
Fields
chains: HashMap<FontChainKeyOrRef, FontFallbackChain>Map from FontChainKeyOrRef to the resolved FontFallbackChain For FontChainKeyOrRef::Ref variants, the FontFallbackChain contains a single-font chain that covers the entire Unicode range.
Implementations
Sourceimpl ResolvedFontChains
impl ResolvedFontChains
Sourcepub fn get(&self, key: &FontChainKeyOrRef) -> Option<&FontFallbackChain>
pub fn get(&self, key: &FontChainKeyOrRef) -> Option<&FontFallbackChain>
Get a font chain by its key
Sourcepub fn get_by_chain_key(&self, key: &FontChainKey) -> Option<&FontFallbackChain>
pub fn get_by_chain_key(&self, key: &FontChainKey) -> Option<&FontFallbackChain>
Get a font chain by FontChainKey (for system fonts)
Sourcepub fn get_for_font_stack(
&self,
font_stack: &[FontSelector],
) -> Option<&FontFallbackChain>
pub fn get_for_font_stack( &self, font_stack: &[FontSelector], ) -> Option<&FontFallbackChain>
Get a font chain for a font stack (via fontconfig)
Sourcepub fn get_for_font_ref(&self, ptr: usize) -> Option<&FontFallbackChain>
pub fn get_for_font_ref(&self, ptr: usize) -> Option<&FontFallbackChain>
Get a font chain for a FontRef pointer
Sourcepub fn into_inner(self) -> HashMap<FontChainKeyOrRef, FontFallbackChain>
pub fn into_inner(self) -> HashMap<FontChainKeyOrRef, FontFallbackChain>
Consume self and return the inner HashMap with FontChainKeyOrRef keys
This is useful when you need access to both Chain and Ref variants.
Sourcepub fn into_fontconfig_chains(self) -> HashMap<FontChainKey, FontFallbackChain>
pub fn into_fontconfig_chains(self) -> HashMap<FontChainKey, FontFallbackChain>
Consume self and return only the fontconfig-resolved chains
This filters out FontRef entries and returns only the chains resolved via fontconfig. This is what FontManager expects.
Sourcepub fn font_refs_len(&self) -> usize
pub fn font_refs_len(&self) -> usize
Get the number of direct FontRefs