Layout tree construction from a styled DOM, including anonymous box generation
Structs
- Cached
Inline Layout - Cached inline layout result with the constraints used to compute it.
- Computed
Layout Style - Pre-computed CSS properties needed during layout.
- IfcId
- Unique identifier for an Inline Formatting Context (IFC).
- IfcMembership
- Tracks a layout node’s membership in an Inline Formatting Context.
- Inline
Item Metrics - Per-item metrics cached from the last IFC layout.
- Layout
Node - A layout tree node representing the CSS box model.
- Layout
Node Cold - Cold layout node fields — construction / reconciliation / debugging only.
- Layout
Node Hot - Hot layout node fields — accessed on every node in every layout pass.
- Layout
Node Warm - Warm layout node fields — accessed frequently but not on every node.
- Layout
Tree - The complete layout tree structure.
- Layout
Tree Builder - Incrementally builds a
LayoutTreefrom aStyledDom. - Layout
Tree Memory Report - Approximate per-field heap-byte breakdown of a
LayoutTree. - Subtree
Hash - A hash that represents the content and style of a node PLUS all of its descendants.
If two
SubtreeHashesare equal, their entire subtrees are considered identical for layout purposes.
Enums
- Anonymous
BoxType - Types of anonymous boxes that can be generated
- Dirty
Flag - Represents the invalidation state of a layout node.
- Pseudo
Element - CSS pseudo-elements that can be generated
Functions
- generate_
layout_ tree - Generate layout tree from styled DOM with proper anonymous box generation
- get_
display_ type - is_
block_ level - is_
whitespace_ only_ text - CSS 2.2 Section 17.2.1 - Anonymous box generation, Stage 1: