pub struct PaginationContext<'a> {
pub geometer: &'a PageGeometer,
pub break_avoid_depth: usize,
pub repeated_headers: Vec<RepeatedTableHeader>,
}Expand description
Context for pagination during layout.
This is passed into layout functions to allow them to make page-aware decisions.
Fields
geometer: &'a PageGeometerThe page geometry calculator
break_avoid_depth: usizeAccumulated break-inside: avoid depth from ancestors
repeated_headers: Vec<RepeatedTableHeader>Track table headers that need to repeat on new pages
Implementations
Sourceimpl<'a> PaginationContext<'a>
impl<'a> PaginationContext<'a>
pub fn new(geometer: &'a PageGeometer) -> Self
Sourcepub fn enter_avoid_break(&mut self)
pub fn enter_avoid_break(&mut self)
Enter a box with break-inside: avoid
Sourcepub fn exit_avoid_break(&mut self)
pub fn exit_avoid_break(&mut self)
Exit a box with break-inside: avoid
Sourcepub fn is_avoiding_breaks(&self) -> bool
pub fn is_avoiding_breaks(&self) -> bool
Check if we’re inside an ancestor with break-inside: avoid