Final positioning of layout nodes (relative, absolute, and fixed schemes)
Structs
- Sticky
Constraints - Sticky positioning constraints computed at layout time. At scroll time, the sticky box’s position is clamped so that it remains within the sticky view rectangle (scrollport inset by these values).
Functions
- adjust_
relative_ positions - Final pass to shift relatively positioned elements from their static flow position.
- adjust_
sticky_ positions - Adjusts positions of sticky-positioned elements based on scroll offset.
- find_
absolute_ containing_ block_ rect - Helper to find the containing block for an absolutely positioned element. CSS 2.1 Section 10.1: The containing block for absolutely positioned elements is the padding box of the nearest positioned ancestor.
- get_
position_ type - Looks up the
positionproperty using the compact-cache-aware getter. - position_
out_ of_ flow_ elements - After the main layout pass, this function iterates through the tree and correctly
calculates the final positions of out-of-flow elements (
absolute,fixed).