Text shaping, line breaking (Knuth-Plass), and inline formatting. Text layout and shaping system.
This module provides text shaping, inline layout, editing, selection, and font caching. Submodules:
cache: unified text layout cache (UnifiedLayout)default: default text shaping and line-breakingedit: text editing operationsglyphs: glyph positioning and cluster mappingknuth_plass: Knuth-Plass line-breaking algorithmmock_fonts: built-in test fonts with exactly known metricsscript: Unicode script detectionselection: text selection and cursor utilities
Modules
- cache
- Core types and layout pipeline for the text/inline formatting context.
- default
- Default / concrete implementations of the text3 trait abstractions.
- edit
- Pure functions for editing a
Vec<InlineContent>based on selections. - glyphs
- A helper module to extract final, absolute glyph positions from a layout. This is useful for renderers that work with simple lists of glyphs.
- knuth_
plass - An implementation of the Knuth-Plass line-breaking algorithm for simple rectangular layouts.
- mock_
fonts - Built-in MOCK FONTS with fully controlled metrics.
- script
- Unicode script detection and language identification for text shaping
- selection
- Text selection helper functions