is_zero_width_space

Function is_zero_width_space 

pub fn is_zero_width_space(item: &ShapedItem) -> bool
Helper to identify if an item is a zero-width space (U+200B), which provides a soft wrap opportunity with no visible width. Used in scripts like Thai, Lao, and Khmer that don’t use spaces between words.