pub fn delete_forward(
content: &mut Vec<InlineContent>,
cursor: &TextCursor,
) -> (Vec<InlineContent>, TextCursor)Expand description
Deletes one grapheme cluster forward from the cursor.
The cursor’s affinity determines the actual cursor position:
Leading: Cursor is at start of cluster, delete the current graphemeTrailing: Cursor is at end of cluster, delete the next grapheme