Thread callback wrappers for the C API. Thread callback information and utilities for azul-layout
This module provides thread-related callback structures for background tasks that need to interact with the UI thread and query layout information.
Structs
- Create
Thread Callback - Library
Receive Thread MsgCallback - Thread
- Wrapper around Thread because Thread needs to be clone-able
- Thread
Callback - Thread
Destructor Callback - Thread
Inner - A
Threadis a separate thread that is owned by the framework. - Thread
Send Callback - Thread
Sender - ThreadSender allows sending messages from the background thread to the main thread
- Thread
Sender Destructor Callback - Thread
Sender Inner - Inner state of a
ThreadSender, holding the channel sender and associated callbacks - Thread
Write Back Msg - Message containing writeback data and callback
- Write
Back Callback - Callback that can run when a thread receives a
WriteBackmessage
Enums
- Option
Thread - Optional Thread type for API compatibility
- Option
Thread Receive Msg - Thread
Receive Msg - Message that is sent back from the running thread to the main thread
Statics
- THREAD_
CALLBACK_ INVOKER - Process-global slot for this callback kind’s host-side invoker.
Functions
- AzApp_
setThread Callback Invoker - Register the host-side invoker for this callback kind.
- AzThread
Callback_ create From Host Handle - C-ABI export wrapping
<Wrapper>::create_from_host_handle. - create_
thread_ libstd - Create a new thread using the standard library
- thread_
sleep_ ms - Sleeps the current thread for the specified number of milliseconds.
- thread_
sleep_ ns - Sleeps the current thread for the specified number of nanoseconds.
- thread_
sleep_ us - Sleeps the current thread for the specified number of microseconds.
Type Aliases
- AzThread
Callback Invoker - Pointer-arg variant of this callback kind’s typedef.
- Create
Thread Callback Type - Function that creates a new Thread object
- Library
Receive Thread MsgCallback Type - Callback type for receiving messages from a background thread
- Thread
Callback Type - Callback type for the function that runs in the background thread
- Thread
Destructor Callback Type - Callback type for the destructor that cleans up a
ThreadInner - Thread
Send Callback Type - Callback for sending messages from thread to main thread
- Thread
Sender Destructor Callback Type - Destructor callback for ThreadSender
- Write
Back Callback Type - Callback that runs when a thread receives a
WriteBackmessage