Timer callback wrappers for the C API. Timer callback information and utilities for azul-layout
This module provides Timer, TimerCallbackInfo and related types for managing timers that run on the main UI thread.
Structs
- Timer
- A
Timeris a function that runs on every frame or at intervals. - Timer
Callback - Callback that runs on every frame on the main thread
- Timer
Callback Info - Information passed to timer callbacks.
Enums
- Option
Timer - Optional Timer type for API compatibility
Type Aliases
- Timer
Callback Type - Callback type for timers