File input widget
File input button, same as Button, but triggers a
user-supplied path-change callback when clicked
Structs
- File
Input - File
Input OnPath Change - File
Input OnPath Change Callback - File
Input State - Current state of the file input (selected path)
- File
Input State Wrapper
Enums
Statics
- FILE_
INPUT_ ON_ PATH_ CHANGE_ INVOKER - Process-global slot for this callback kind’s host-side invoker.
Functions
- AzApp_
setFile Input OnPath Change Callback Invoker - Register the host-side invoker for this callback kind.
- AzFile
Input OnPath Change Callback_ create From Host Handle - C-ABI export wrapping
<Wrapper>::create_from_host_handle.
Type Aliases
- AzFile
Input OnPath Change Callback Invoker - Pointer-arg variant of this callback kind’s typedef.
- File
Input OnPath Change Callback Type - Callback type invoked when the file input path changes