Module node_graph

Module node_graph 

Node graph widget

Structs

GraphDragAmount
InputConnection
InputConnectionVec
InputConnectionVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
InputNodeAndIndex
InputNodeAndIndexVec
InputNodeAndIndexVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
InputOutputInfo
InputOutputTypeId
InputOutputTypeIdInfoMap
InputOutputTypeIdInfoMapVec
InputOutputTypeIdInfoMapVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
InputOutputTypeIdVec
InputOutputTypeIdVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
Node
NodeDragAmount
NodeGraph
Same as the NodeGraph but without generics and without the actual data
NodeGraphCallbacks
NodeGraphNodeId
NodeGraphNodePosition
Things only relevant to the display of the node in an interactive editor
NodeIdNodeMap
NodeIdNodeMapVec
NodeIdNodeMapVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
NodeTypeField
NodeTypeFieldVec
NodeTypeFieldVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
NodeTypeId
NodeTypeIdInfoMap
NodeTypeIdInfoMapVec
NodeTypeIdInfoMapVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
NodeTypeInfo
OnNodeAdded
OnNodeAddedCallback
OnNodeConnected
OnNodeConnectedCallback
OnNodeDragged
OnNodeDraggedCallback
OnNodeFieldEdited
OnNodeFieldEditedCallback
OnNodeGraphDragged
OnNodeGraphDraggedCallback
OnNodeInputDisconnected
OnNodeInputDisconnectedCallback
OnNodeOutputDisconnected
OnNodeOutputDisconnectedCallback
OnNodeRemoved
OnNodeRemovedCallback
OutputConnection
OutputConnectionVec
OutputConnectionVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.
OutputNodeAndIndex
OutputNodeAndIndexVec
OutputNodeAndIndexVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.

Enums

InputConnectionVecDestructor
InputNodeAndIndexVecDestructor
InputOutputTypeIdInfoMapVecDestructor
InputOutputTypeIdVecDestructor
NodeGraphError
NodeGraphStyle
NodeIdNodeMapVecDestructor
NodeTypeFieldValue
NodeTypeFieldVecDestructor
NodeTypeIdInfoMapVecDestructor
OptionInputConnection
OptionInputNodeAndIndex
OptionInputOutputTypeId
OptionInputOutputTypeIdInfoMap
OptionNodeIdNodeMap
OptionNodeTypeField
OptionNodeTypeIdInfoMap
OptionOnNodeAdded
OptionOnNodeConnected
OptionOnNodeDragged
OptionOnNodeFieldEdited
OptionOnNodeGraphDragged
OptionOnNodeInputDisconnected
OptionOnNodeOutputDisconnected
OptionOnNodeRemoved
OptionOutputConnection
OptionOutputNodeAndIndex
OutputConnectionVecDestructor
OutputNodeAndIndexVecDestructor

Type Aliases

InputConnectionVecDestructorType
InputNodeAndIndexVecDestructorType
InputOutputTypeIdInfoMapVecDestructorType
InputOutputTypeIdVecDestructorType
NodeIdNodeMapVecDestructorType
NodeTypeFieldVecDestructorType
NodeTypeIdInfoMapVecDestructorType
OnNodeAddedCallbackType
OnNodeConnectedCallbackType
OnNodeDraggedCallbackType
OnNodeFieldEditedCallbackType
OnNodeGraphDraggedCallbackType
OnNodeInputDisconnectedCallbackType
OnNodeOutputDisconnectedCallbackType
OnNodeRemovedCallbackType
OutputConnectionVecDestructorType
OutputNodeAndIndexVecDestructorType