pub fn get_html_node(
root_nodes: &[XmlNodeChild],
) -> Result<&XmlNode, DomXmlParseError>Expand description
Find the one and only <body> node, return error if
there is no app node or there are multiple app nodes
Errors
Returns an error if the document has no <html> root node.